<template>
	<div class="flex flex-col h100">
		<el-row class="w100 h100">
			<el-col :span="17">
				<div class="h100 relative">
					<div class="ml-6 h100">
						<el-tabs v-model="state.activeMetricName" @tab-change="handleClick" class="h100">
							<el-tab-pane label="基础信息" name="basicInformation">
								<div class="h100">
									<el-descriptions title="指标信息" :column="2">
										<el-descriptions-item label="指标名称:">{{
											state.descriptionQuotaItems.title ? state.descriptionQuotaItems.title : '-'
										}}</el-descriptions-item>
										<el-descriptions-item label="指标全称:">{{
											state.descriptionQuotaItems.full_name ? state.descriptionQuotaItems.full_name : '-'
										}}</el-descriptions-item>
										<el-descriptions-item label="指标定义:">{{
											state.descriptionQuotaItems.metrics_define ? state.descriptionQuotaItems.metrics_define : '-'
										}}</el-descriptions-item>
										<el-descriptions-item label="类别:">
											{{
												state.descriptionQuotaItems.metrics_type ? state.descriptionQuotaItems.metrics_type : '-'
											}}</el-descriptions-item
										>
										<el-descriptions-item label="重要性:">
											<el-tag size="small" :style="{ backgroundColor: 'e6f4ff', color: '#0958d9', borderColor: '#91caff' }">{{
												eMetrics_Ops[state.descriptionQuotaItems.metrics_important]
											}}</el-tag>
										</el-descriptions-item>
										<el-descriptions-item label="计算方法:">
											{{ state.descriptionQuotaItems.calcu_method ? state.descriptionQuotaItems.calcu_method : '-' }}
										</el-descriptions-item>
									</el-descriptions>
									<el-divider />
								</div>
							</el-tab-pane>
							<el-tab-pane label="指标探索" name="indicatorExploration">
								<div class="h100">
									<div class="set_explore">
										<div class="set_explore_pad">
											<el-form ref="exploreFormRef" :model="state.exploreForm" label-width="80px" label-position="left">
												<el-form-item label="日期区间:">
													<div style="width: 300px">
														<el-date-picker
															v-model="state.exploreForm.dateRangeExplore"
															type="daterange"
															range-separator="~"
															value-format="YYYY-MM-DD HH:mm:ss"
															:default-time="defaultTime"
															@change="getDateTime"
															:disabled-date="disablesDate"
														/>
													</div>
												</el-form-item>
												<el-form-item label="维度下钻:">
													<el-select v-model="state.exploreForm.dimensionDrilling" autocomplete="off" style="width: 226.4px" clearable>
														<el-option
															v-for="item in Object.keys(eDrilling_Ops)"
															:key="item"
															:value="parseInt(item)"
															:label="eDrilling_Ops[item]"
														>
														</el-option>
													</el-select>
												</el-form-item>
												<el-form-item label="维度筛选:">
													<el-select
														v-model="state.exploreForm.dimensionFiltering.user"
														autocomplete="off"
														style="width: 186.4px"
														clearable
														@change="handleDimensionFilteringChange"
													>
														<el-option
															v-for="item in Object.keys(eDrilling_Ops)"
															:key="item"
															:value="parseInt(item)"
															:label="eDrilling_Ops[item]"
														>
														</el-option>
													</el-select>
													<el-select
														v-model="state.exploreForm.dimensionFiltering.unit"
														autocomplete="off"
														style="width: 126.4px; margin: 0 5px"
														clearable
													>
														<el-option
															v-for="item in Object.keys(eDimensionFilter_Ops)"
															:key="item"
															:value="parseInt(item)"
															:label="eDimensionFilter_Ops[item]"
														>
														</el-option>
													</el-select>
													<el-select v-model="state.resultList" autocomplete="off" style="width: 126.4px; margin-right: 5px" clearable>
														<el-option
															v-for="(item, index) in state.resultList"
															:key="index"
															:value="item.department"
															:label="item.department"
														>
														</el-option>
													</el-select>
													<el-button type="primary" @click="handleExplore" icon="ele-Search">查询</el-button>
												</el-form-item>
											</el-form>
										</div>
										<div class="w100 h-[550px]">
											<div ref="chartExplorationRef" class="w100 h100"></div>
										</div>
									</div>
								</div>
							</el-tab-pane>
						</el-tabs>
					</div>
					<div class="list_btn" @click="handleExitFlow">
						<el-button style="width: 40px" link>
							<el-icon style="font-size: 16px !important; color: #1677ff">
								<ArrowLeft />
							</el-icon>
						</el-button>
						<span class="text-[14px] text-[#1677ff] font-[400] mr-2">返回列表页</span>
					</div>
				</div>
			</el-col>
			<el-col :span="7">
				<div class="set-right-height ml-[10px]">
					<div class="mb-[5px]">
						<div class="set-visit">
							<i class="ywifont ywicon-fenshu_an w-[18px] h-[18px] text-yellow-300 !text-[20px]"></i>
							<div>访问次数</div>
						</div>
					</div>
					<div class="set-detail">
						<el-divider />
						<div class="section___vePzi">
							<div class="item___txXyB" v-for="(item, index) in state.metricBasicInfo.visitNumData" :key="index">
								<div class="item_name">{{ item.name }}:</div>
								<div class="item_value">
									{{ item.value }}
								</div>
							</div>
						</div>
						<el-divider />
						<div class="section___vePzi">
							<div class="item___title">
								<i class="ywifont ywicon-gongzuozongjie w-[18px] h-[18px] !text-[18px]"></i>
								<span>创建信息</span>
							</div>
							<div class="item___txXyB" v-for="(item, index) in state.metricBasicInfo.createInformation" :key="index">
								<div class="item_name">{{ item.name }}:</div>
								<div class="item_value">
									{{ item.value }}
								</div>
							</div>
						</div>
						<el-divider />
						<div class="section___vePzi">
							<div class="item___title">
								<i class="ywifont ywicon-jiankong w-[18px] h-[18px] !text-[20px]"></i>
								<span>应用信息 </span>
							</div>
							<div class="text-[#344767]">
								<div class="item___bg">
									<div class="block px-[16px] py-[4px]">
										<div class="subTitle___zya5g">下钻维度</div>
										<div class="ml-0 mt-[20px]">
											<div class="flex flex-wrap gap-[5px] items-center">
												<div v-for="item in state.metricBasicInfo.applicationInformation" :key="item.id">
													<el-tag :style="{ backgroundColor: 'e6f4ff', color: '#0958d9', borderColor: '#91caff' }">{{
														item.title
													}}</el-tag>
												</div>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</el-col>
		</el-row>
	</div>
</template>

<script setup lang="ts">
import * as echarts from 'echarts';
import { nextTick, onMounted, reactive, ref } from 'vue';
import { useRoute, useRouter } from 'vue-router';
import * as metricApi from '/@/api/metrics';
import { formatTime, getDefaultPeriod } from '/@/utils/istation/common.js';
import { eMetrics_Ops } from '/@/views/types/metrics';
import { eDimensionFilter_Ops, eDrilling_Ops } from '/@/views/types/metrics/index';
const defaultTime = ref<[Date, Date]>([new Date(2000, 1, 1, 0, 0, 0), new Date(2000, 2, 1, 23, 59, 59)]);
const router = useRouter();
const route = useRoute();
// 定义变量内容
const state = reactive({
	metricInfo: {
		name: '',
		id: '',
	} as any,
	activeMetricName: 'basicInformation',
	descriptionQuotaItems: {} as any,
	metricBasicInfo: {
		visitNumData: [
			{
				name: '重要性',
				value: '',
			},
			{
				name: '所属模型',
				value: '',
			},
			{
				name: '描述',
				value: '',
			},
		],
		createInformation: [
			{
				name: '创建人',
				value: 'admin',
			},
			{
				name: '创建时间',
				value: '2024-10-08 10:03:39',
			},
			{
				name: '更新时间',
				value: '2024-10-08 14:12:11',
			},
		],
		applicationInformation: [],
	},
	exploreForm: {
		dateRangeExplore: '' as any,
		dimensionDrilling: 0,
		dimensionFiltering: {
			user: '',
			unit: '',
			someone: '',
		},
	},
	resultList: [
		{
			department: 'HR',
		},
		{
			department: 'marketing',
		},
		{
			department: 'sales',
		},
		{
			department: 'strategy',
		},
	],
	chartStatus: false,
});

//返回到知识库列表
const handleExitFlow = () => {
	//是否显示返回
	router.back();
};

//#endregion
//#region ====================== 基础信息 ======================
const tableData = ref([]);
const getTableData = async (id) => {
	const res = await metricApi.getMetricNameListByPost();
	const data = res?.values ?? [];
	const filterData = data.filter((item) => item.id == id);
	state.descriptionQuotaItems = filterData[0];
	state.metricBasicInfo.visitNumData = [
		{
			name: '重要性',
			value: eMetrics_Ops[filterData[0].metrics_important],
		},
		{
			name: '所属模型',
			value: '-',
		},
		{
			name: '描述',
			value: filterData[0].metrics_define,
		},
	];
	state.metricBasicInfo.applicationInformation = filterData[0].dimensions;
};
//#endregion
//#region ====================== 指标探索查询 ======================
// 时间限制
const disablesDate = (time) => {
	return time.getTime() > new Date().getTime();
};
//获取日期的时间
const getDateTime = (val) => {
	state.exploreForm.dateRangeExplore[0] = val[0];
	state.exploreForm.dateRangeExplore[1] = val[1];
};
const handleDimensionFilteringChange = (val) => {
	state.exploreForm.dimensionFiltering.user = val;
};
const handleExplore = () => {
	console.log(state.exploreForm);
};
//#endregion

//#region ====================== 图表resize ======================
const getChartInstance = (chartRef: HTMLDivElement) => {
	let chartInstance = echarts.getInstanceByDom(chartRef);
	if (chartInstance) return chartInstance;
	const { width, height } = chartRef.getBoundingClientRect();
	chartInstance = echarts.init(chartRef, undefined, {
		width,
		height,
	});
	window.addEventListener('resize', () => {
		const { width, height } = chartRef.getBoundingClientRect();
		chartInstance = echarts.init(chartRef, undefined, {
			width,
			height,
		});
		chartInstance.resize({ width, height });
	});
	return chartInstance;
};
const resizeChart = () => {
	const { width, height } = chartExplorationRef.value.getBoundingClientRect();
	const chartInstance = getChartInstance(chartExplorationRef.value);
	chartInstance && chartInstance.resize({ width, height });
};
//#endregion
//#region ====================== init 图表 ======================
const chartExplorationRef = ref(null);
const initChartExploration = () => {
	const testData = [
		{
			sys_imp_date: '2024-10-03',
			stay_hours: 5.058984585654882,
		},
		{
			sys_imp_date: '2024-10-05',
			stay_hours: 10.25773691448837,
		},
		{
			sys_imp_date: '2024-10-06',
			stay_hours: 8.523378141884379,
		},
		{
			sys_imp_date: '2024-10-07',
			stay_hours: 7.073257474459168,
		},
		{
			sys_imp_date: '2024-10-08',
			stay_hours: 6.69083423985072,
		},
	];
	let xData = [];
	let yData = [];
	testData.forEach((item) => {
		xData.push(item.sys_imp_date);
		yData.push(item.stay_hours);
	});
	const chartExploration = {
		tooltip: {
			trigger: 'axis',
		},
		grid: {
			top: 70,
			left: 10,
			right: 40,
			bottom: 0,
			containLabel: true,
		},
		xAxis: {
			name: '日期',
			type: 'category',

			axisTick: {
				alignWithLabel: true,
			},
			data: xData,
			axisLabel: {
				formatter: function (value) {
					const date = new Date(value);
					return formatTime('yyyy-MM-dd', date);
				},
			},
		},
		yAxis: [
			{
				type: 'value',
				name: '停留时长',
				nameGap: 30,
			},
		],
		series: [
			{
				name: 'PV',
				type: 'line',
				stack: '总量',
				data: yData,
			},
		],
	};
	const chartInstance = getChartInstance(chartExplorationRef.value);
	chartInstance.setOption(chartExploration);
	chartInstance.resize();
};
const handleClick = (val) => {
	const { startDate, endDate } = getDefaultPeriod('7Days');
	const dateRange = [startDate.format('YYYY-MM-DD HH:mm:ss'), endDate.format('YYYY-MM-DD HH:mm:ss')];
	state.exploreForm.dateRangeExplore = dateRange;
	if (val == 'indicatorExploration') {
		nextTick(() => {
			if (state.chartStatus) {
				resizeChart();
				return;
			}
			initChartExploration();
			state.chartStatus = true;
		});
	}
	state.activeMetricName = val;
};
//#endregion
onMounted(() => {
	const { id } = route.query;
	getTableData(id);
});
</script>
<style scoped lang="scss">
:deep(.el-tabs__header) {
	background-color: #fff;
	border-radius: 8px;
}
:deep(.el-tabs__content) {
	height: 100%;
	background-color: #fff;
	border-radius: 16px;
	overflow-y: auto;
	padding: 10px 20px;
	box-sizing: border-box;
}
.set-right-height {
	padding: 20px;
	color: #344767;
	background-color: #fff;
	height: 100%;
	border-radius: 6px;
	.set-visit {
		box-sizing: border-box;
		column-gap: 8px;
		row-gap: 8px;
		align-items: center;
		display: inline-flex;
		font-weight: 600;
		font-size: 18px;
	}
	.set-detail {
		width: 100%;
		height: calc(100% - 92px);
		position: relative;
		display: flex;
		flex-direction: column;
		overflow: scroll;
		overflow: hidden;
		background-image: none;
		border-radius: 6px;
		.section___vePzi {
			padding: 0px 16px;
			color: #344767;
			line-height: 1.25;
			background: transparent;
			box-shadow: none;
			opacity: 1;
			.item___title {
				padding: unset;
				color: #344767;
				background: transparent;
				box-shadow: none;
				opacity: 1;
				span {
					margin-left: 8px;
					color: #344767;
					font-weight: 600;
					font-size: 16px;
					line-height: 1.625;
					letter-spacing: 0.0075em;
					text-transform: capitalize;
					text-decoration: none;
					vertical-align: unset;
					opacity: 1;
				}
			}
			.item___txXyB {
				display: flex;
				padding-top: 8px;
				padding-right: 16px;
				padding-bottom: 8px;
				color: #344767;
				background: transparent;
				box-shadow: none;
				opacity: 1;
				.item_name {
					min-width: fit-content;
					margin: 0 10px 0 0;
					color: #344767;
					font-weight: 700;
					font-size: 14px;
					line-height: 1.5;
					letter-spacing: 0.02857em;
					text-transform: capitalize;
					text-decoration: none;
					vertical-align: unset;
					opacity: 1;
				}
				.item_value {
					margin: 0;
					color: #7b809a;
					font-weight: 400;
					font-size: 14px;
					line-height: 1.5;
					letter-spacing: 0.02857em;
					text-transform: none;
					text-decoration: none;
					vertical-align: unset;
					opacity: 1;
				}
			}
			.item___bg {
				position: relative;
				margin: 0;
				padding: 8px 0;
				list-style: none;
				background-color: #f9fafb;
				.subTitle___zya5g {
					margin: 0;
					color: #7b809a;
					font-weight: 700;
					font-size: 14px;
					line-height: 1.25;
					letter-spacing: 0.03333em;
					text-transform: uppercase;
					text-decoration: none;
					vertical-align: unset;
					opacity: 1;
				}
			}
		}
	}
}
.activeColor {
	border-color: #0062be;
	background-color: #f6f5ff;
}
.list_btn {
	outline: none;
	position: absolute;
	top: 0;
	right: 0;
	display: inline-block;
	font-weight: 400;
	white-space: nowrap;
	text-align: center;
	background-image: none;
	background-color: transparent;
	border: 1px solid transparent;
	cursor: pointer;
	transition: all 0.2s cubic-bezier(0.645, 0.045, 0.355, 1);
	user-select: none;
	touch-action: manipulation;
	line-height: 1.5714285714285714;
	margin-top: 5px;
	margin-right: 6px;
}
.set_explore {
	position: relative;
	overflow: hidden;
	background-color: #fff;
	background-image: none;
	border-radius: 6px;
	// box-shadow: #888 0 0 1px, #1d293914 0 1px 3px;
	transition: box-shadow 0.3s cubic-bezier(0.4, 0, 0.2, 1) 0ms;
	&_pad {
		padding: 10px 10px 0px;
	}
}
</style>
